@@ -17,12 +17,12 @@ const (
 
 // Properties
 
-func (p properties) getOneOfBool(property, legacyProperty Property) bool {
+func (p properties) getOneOfBool(property, legacyProperty Property, defaultValue bool) bool {
 	_, found := p[legacyProperty]
 	if found {
-		return p.getBool(legacyProperty, false)
+		return p.getBool(legacyProperty, defaultValue)
 	}
-	return p.getBool(property, false)
+	return p.getBool(property, defaultValue)
 }
 
 func (p properties) hasOneOf(properties ...Property) bool {
@@ -87,13 +87,15 @@ func (g *git) deprecatedString(statusColorsEnabled bool) string {
 	if len(g.BranchStatus) > 0 {
 		buffer.WriteString(g.BranchStatus)
 	}
-	if g.Staging.Changed {
+
+	// status
+	if g.Staging.Changed() {
 		fmt.Fprint(buffer, g.getStatusDetailString(g.Staging, StagingColor, LocalStagingIcon, " \uF046"))
 	}
-	if g.Staging.Changed && g.Working.Changed {
+	if g.Staging.Changed() && g.Working.Changed() {
 		fmt.Fprint(buffer, g.props.getString(StatusSeparatorIcon, " |"))
 	}
-	if g.Working.Changed {
+	if g.Working.Changed() {
 		fmt.Fprint(buffer, g.getStatusDetailString(g.Working, WorkingColor, LocalWorkingIcon, " \uF044"))
 	}
 	if g.StashCount != 0 {
@@ -114,7 +116,7 @@ func (g *git) SetStatusColor() {
 }
 
 func (g *git) getStatusColor(defaultValue string) string {
-	if g.Staging.Changed || g.Working.Changed {
+	if g.Staging.Changed() || g.Working.Changed() {
 		return g.props.getColor(LocalChangesColor, defaultValue)
 	} else if g.Ahead > 0 && g.Behind > 0 {
 		return g.props.getColor(AheadAndBehindColor, defaultValue)
@@ -254,6 +256,8 @@ const (
 	DisplayUser Property = "display_user"
 	// DefaultUserName holds the default user of the platform
 	DefaultUserName Property = "default_user_name"
+	// SSHIcon is the icon used for SSH sessions
+	SSHIcon Property = "ssh_icon"
 
 	defaultUserEnvVar = "POSH_SESSION_DEFAULT_USER"
 )
@@ -304,3 +308,100 @@ func (s *session) getFormattedText() string {
 	}
 	return fmt.Sprintf("%s%s%s%s", sshIcon, s.UserName, separator, s.ComputerName)
 }
+
+// Language
+
+const (
+	// DisplayVersion show the version number or not
+	DisplayVersion Property = "display_version"
+	// VersionMismatchColor displays empty string by default
+	VersionMismatchColor Property = "version_mismatch_color"
+	// EnableVersionMismatch displays empty string by default
+	EnableVersionMismatch Property = "enable_version_mismatch"
+)
+
+func (l *language) string() string {
+	if !l.props.getOneOfBool(FetchVersion, DisplayVersion, true) {
+		return ""
+	}
+
+	err := l.setVersion()
+	if err != nil {
+		l.Error = err.Error()
+	}
+	displayError := l.props.getBool(DisplayError, true)
+	if err != nil && displayError {
+		return err.Error()
+	}
+	if err != nil {
+		return ""
+	}
+
+	segmentTemplate := l.props.getString(SegmentTemplate, "{{ .Full }}")
+	template := &textTemplate{
+		Template: segmentTemplate,
+		Context:  l.version,
+		Env:      l.env,
+	}
+	text, err := template.render()
+	if err != nil {
+		return err.Error()
+	}
+
+	if l.props.getBool(EnableHyperlink, false) {
+		versionURLTemplate := l.props.getString(VersionURLTemplate, "")
+		// backward compatibility
+		if versionURLTemplate == "" {
+			text = l.buildVersionURL(text)
+		} else {
+			template := &textTemplate{
+				Template: versionURLTemplate,
+				Context:  l.version,
+				Env:      l.env,
+			}
+			url, err := template.render()
+			if err != nil {
+				return err.Error()
+			}
+			text = url
+		}
+	}
+
+	if l.props.getBool(EnableVersionMismatch, false) {
+		l.setVersionFileMismatch()
+	}
+	return text
+}
+
+func (l *language) colorMismatch() {
+	if l.props.getBool(ColorBackground, false) {
+		l.props[BackgroundOverride] = l.props.getColor(VersionMismatchColor, l.props.getColor(BackgroundOverride, ""))
+		return
+	}
+	l.props[ForegroundOverride] = l.props.getColor(VersionMismatchColor, l.props.getColor(ForegroundOverride, ""))
+}
+
+// Python
+
+const (
+	// DisplayVirtualEnv shows or hides the virtual env
+	DisplayVirtualEnv Property = "display_virtual_env"
+)
+
+func (p *python) legacyString() string {
+	if p.Venv == "" {
+		return p.language.string()
+	}
+	version := p.language.string()
+	if version == "" {
+		return p.Venv
+	}
+	return fmt.Sprintf("%s %s", p.Venv, version)
+}
+
+// Node
+
+const (
+	// DisplayPackageManager shows if NPM or Yarn is used
+	DisplayPackageManager Property = "display_package_manager"
+)
