@@ -15,6 +15,7 @@ const (
 
 func TestEnabledGitNotFound(t *testing.T) {
 	env := new(MockedEnvironment)
+	env.On("inWSLSharedDrive", nil).Return(false)
 	env.On("hasCommand", "git").Return(false)
 	env.On("getRuntimeGOOS", nil).Return("")
 	env.On("isWsl", nil).Return(false)
@@ -28,6 +29,7 @@ func TestEnabledGitNotFound(t *testing.T) {
 
 func TestEnabledInWorkingDirectory(t *testing.T) {
 	env := new(MockedEnvironment)
+	env.On("inWSLSharedDrive", nil).Return(false)
 	env.On("hasCommand", "git").Return(true)
 	env.On("getRuntimeGOOS", nil).Return("")
 	env.On("isWsl", nil).Return(false)
@@ -48,6 +50,7 @@ func TestEnabledInWorkingDirectory(t *testing.T) {
 
 func TestEnabledInWorkingTree(t *testing.T) {
 	env := new(MockedEnvironment)
+	env.On("inWSLSharedDrive", nil).Return(false)
 	env.On("hasCommand", "git").Return(true)
 	env.On("getRuntimeGOOS", nil).Return("")
 	env.On("isWsl", nil).Return(false)
@@ -66,7 +69,32 @@ func TestEnabledInWorkingTree(t *testing.T) {
 	}
 	assert.True(t, g.enabled())
 	assert.Equal(t, "/dev/real_folder/.git/worktrees/folder_worktree", g.gitWorkingFolder)
-	assert.Equal(t, "/dev/folder_worktree", g.gitWorktreeFolder)
+	assert.Equal(t, "/dev/folder_worktree", g.gitRealFolder)
+}
+
+func TestEnabledInSubmodule(t *testing.T) {
+	env := new(MockedEnvironment)
+	env.On("inWSLSharedDrive", nil).Return(false)
+	env.On("hasCommand", "git").Return(true)
+	env.On("getRuntimeGOOS", nil).Return("")
+	env.On("isWsl", nil).Return(false)
+	fileInfo := &fileInfo{
+		path:         "/dev/parent/test-submodule/.git",
+		parentFolder: "/dev/parent/test-submodule",
+		isDir:        false,
+	}
+	env.On("hasParentFilePath", ".git").Return(fileInfo, nil)
+	env.On("getFileContent", "/dev/parent/test-submodule/.git").Return("gitdir: ../.git/modules/test-submodule")
+	env.On("getFileContent", "/dev/parent/.git/modules/test-submodule").Return("/dev/folder_worktree.git\n")
+	g := &git{
+		scm: scm{
+			env: env,
+		},
+	}
+	assert.True(t, g.enabled())
+	assert.Equal(t, "/dev/parent/test-submodule/../.git/modules/test-submodule", g.gitWorkingFolder)
+	assert.Equal(t, "/dev/parent/test-submodule/../.git/modules/test-submodule", g.gitRealFolder)
+	assert.Equal(t, "/dev/parent/test-submodule/../.git/modules/test-submodule", g.gitRootFolder)
 }
 
 func TestGetGitOutputForCommand(t *testing.T) {
@@ -195,6 +223,7 @@ func TestSetGitHEADContextClean(t *testing.T) {
 	}
 	for _, tc := range cases {
 		env := new(MockedEnvironment)
+		env.On("inWSLSharedDrive", nil).Return(false)
 		env.On("getRuntimeGOOS", nil).Return("unix")
 		env.On("isWsl", nil).Return(false)
 		env.mockGitCommand("", "describe", "--tags", "--exact-match")
@@ -537,17 +566,18 @@ func TestShouldIgnoreRootRepository(t *testing.T) {
 
 func TestGetGitCommand(t *testing.T) {
 	cases := []struct {
-		Case     string
-		Expected string
-		IsWSL    bool
-		IsWSL1   bool
-		GOOS     string
-		CWD      string
+		Case            string
+		Expected        string
+		IsWSL           bool
+		IsWSL1          bool
+		GOOS            string
+		CWD             string
+		IsWslSharedPath bool
 	}{
 		{Case: "On Windows", Expected: "git.exe", GOOS: windowsPlatform},
 		{Case: "Non Windows", Expected: "git"},
 		{Case: "Iside WSL2, non shared", IsWSL: true, Expected: "git"},
-		{Case: "Iside WSL2, shared", Expected: "git.exe", IsWSL: true, CWD: "/mnt/bill"},
+		{Case: "Iside WSL2, shared", Expected: "git.exe", IsWSL: true, IsWslSharedPath: true, CWD: "/mnt/bill"},
 		{Case: "Iside WSL1, shared", Expected: "git", IsWSL: true, IsWSL1: true, CWD: "/mnt/bill"},
 	}
 
@@ -566,6 +596,12 @@ func TestGetGitCommand(t *testing.T) {
 				env: env,
 			},
 		}
+		if tc.IsWslSharedPath {
+			env.On("inWSLSharedDrive", nil).Return(true)
+			g.IsWslSharedPath = tc.IsWslSharedPath
+		} else {
+			env.On("inWSLSharedDrive", nil).Return(false)
+		}
 		assert.Equal(t, tc.Expected, g.getGitCommand(), tc.Case)
 	}
 }
